Installation guide — Group Lasso 1.3.1 documentation

# Installation guide

## Dependencies

`group-lasso` support Python 3.5+, Additionally, you will need `numpy`, `scikit-learn` and `scipy`. Hosever, these packages should be installed automatically when installing this codebase.

## Installing group-lasso

`group-lasso` is available through Pypi and can easily be installed with a pip install:

    pip install group-lasso

The Pypi version is updated regularly, however for the latest update, you should clone from GitHub and install it directly.:

    git clone https://github.com/yngvem/group-lasso.git
    cd group-lasso
    python setup.py